"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const useQuizResultsLoaded_1 = tslib_1.__importDefault(require("./useQuizResultsLoaded"));
const useQuizResultClick_1 = tslib_1.__importDefault(require("./useQuizResultClick"));
const useQuizAddToCart_1 = tslib_1.__importDefault(require("./useQuizAddToCart"));
const useQuizBackClick_1 = tslib_1.__importDefault(require("./useQuizBackClick"));
const useQuizAnswerChangeHandler_1 = tslib_1.__importDefault(require("./useQuizAnswerChangeHandler"));
const useQuizNextClick_1 = tslib_1.__importDefault(require("./useQuizNextClick"));
const useQuizResetClick_1 = tslib_1.__importDefault(require("./useQuizResetClick"));
const useHydrateQuizLocalState_1 = tslib_1.__importDefault(require("./useHydrateQuizLocalState"));
const utils_1 = require("../../utils");
const useQuizEvents = (quizOptions, cioClient, quizState) => {
    const { quizApiState, dispatchLocalState, dispatchApiState, hasQuizStoredState, quizStateKey, quizLocalState, } = quizState;
    const { resultsPageOptions } = quizOptions;
    const { onAddToCartClick, onQuizResultClick, onQuizResultsLoaded } = resultsPageOptions;
    // Quiz answer change
    const quizAnswerChanged = (0, useQuizAnswerChangeHandler_1.default)(quizApiState, dispatchLocalState);
    // Quiz Next button click callback
    const nextQuestion = (0, useQuizNextClick_1.default)(quizApiState, quizLocalState, dispatchLocalState);
    // Quiz Back button click callback
    const previousQuestion = (0, useQuizBackClick_1.default)(quizApiState, dispatchLocalState);
    // Quiz result add to cart callback
    const addToCart = (0, useQuizAddToCart_1.default)(cioClient, quizApiState, onAddToCartClick);
    // Quiz result click callback
    const resultClick = (0, useQuizResultClick_1.default)(cioClient, quizApiState, onQuizResultClick);
    // Quiz results loaded event
    (0, useQuizResultsLoaded_1.default)(cioClient, quizApiState, onQuizResultsLoaded);
    // Quiz reset
    const resetQuiz = (0, useQuizResetClick_1.default)(quizStateKey, dispatchLocalState, dispatchApiState, quizApiState.quizResults);
    // Quiz rehydrate
    const hydrateQuizLocalState = (0, useHydrateQuizLocalState_1.default)(quizStateKey, dispatchLocalState);
    return {
        addToCart,
        resultClick,
        quizAnswerChanged,
        previousQuestion,
        nextQuestion,
        resetQuiz,
        hydrateQuiz: hydrateQuizLocalState,
        hasSessionStorageState: hasQuizStoredState,
        resetSessionStorageState: (0, utils_1.resetQuizSessionStorageState)(quizStateKey),
    };
};
exports.default = useQuizEvents;
