import React, { useContext } from 'react';
import ResultCtaButton from '../ResultCtaButton/ResultCtaButton';
import QuizContext from '../CioQuiz/context';
export default function ResultCard(props) {
    const { result, salePriceKey, regularPriceKey, resultPosition } = props;
    const { customClickItemCallback, getQuizResultButtonProps, getQuizResultLinkProps } = useContext(QuizContext);
    const salePrice = salePriceKey && result?.data?.[salePriceKey];
    const regularPrice = regularPriceKey && result?.data?.[regularPriceKey];
    const resultCardContent = () => (React.createElement(React.Fragment, null,
        React.createElement("div", { className: 'cio-result-card-image' },
            React.createElement("img", { src: result.data?.image_url, alt: 'product' })),
        React.createElement("div", { className: 'cio-result-card-text' },
            React.createElement("p", { className: 'cio-result-card-title' }, result.value),
            React.createElement("div", { className: 'cio-result-card-prices' },
                salePrice && React.createElement("span", { className: 'cio-result-card-sale-price' },
                    "$",
                    salePrice),
                regularPrice && (React.createElement("span", { className: `cio-result-card-regular-price${salePrice ? '--strike-through' : ''}` },
                    "$",
                    regularPrice))))));
    const resultCardContentWithoutLink = () => getQuizResultButtonProps && (React.createElement("div", { ...getQuizResultButtonProps({ result, position: resultPosition, type: 'button' }) }, resultCardContent()));
    const resultCardContentWithLink = () => getQuizResultLinkProps && (React.createElement("a", { className: 'cio-result-card-anchor', ...getQuizResultLinkProps({ result, position: resultPosition, type: 'link' }) }, resultCardContent()));
    return (React.createElement("div", { className: 'cio-result-card' },
        !customClickItemCallback ? resultCardContentWithLink() : resultCardContentWithoutLink(),
        React.createElement(ResultCtaButton, { item: result, price: salePrice || regularPrice })));
}
