import { CurrentQuestion, NextQuestionResponse, QuizResultsResponse } from '../../types';
import type { QuizLocalReducerState } from './quizLocalReducer';
export declare enum QuestionTypes {
    OpenText = "open",
    Cover = "cover",
    SingleSelect = "single",
    MultipleSelect = "multiple",
    Next = "next",
    Back = "back",
    Reset = "reset",
    Hydrate = "hydrate"
}
export interface QuestionAnswer<Value> {
    questionId: number;
    input: Value;
    isLastQuestion?: boolean;
}
export type SelectQuestionPayload = QuestionAnswer<string[]>;
export type OpenTextQuestionPayload = QuestionAnswer<string>;
export type CoverQuestionPayload = QuestionAnswer<string>;
interface Action<Type, Payload = {}> {
    type: Type;
    payload?: Payload;
}
export type ActionAnswerInputQuestion = Action<QuestionTypes.OpenText, OpenTextQuestionPayload> | Action<QuestionTypes.SingleSelect, SelectQuestionPayload> | Action<QuestionTypes.MultipleSelect, SelectQuestionPayload> | Action<QuestionTypes.Cover, CoverQuestionPayload>;
export type ActionAnswerQuestion = ActionAnswerInputQuestion | Action<QuestionTypes.Next, CurrentQuestion> | Action<QuestionTypes.Back, CurrentQuestion> | Action<QuestionTypes.Reset> | Action<QuestionTypes.Hydrate, Partial<QuizLocalReducerState>>;
export declare enum QuizAPIActionTypes {
    SET_IS_LOADING = 0,
    SET_IS_ERROR = 1,
    SET_QUIZ_RESULTS = 2,
    SET_CURRENT_QUESTION = 3,
    RESET_QUIZ = 4
}
export type ActionSetIsLoading = Action<QuizAPIActionTypes.SET_IS_LOADING>;
export type ActionSetIsError = Action<QuizAPIActionTypes.SET_IS_ERROR>;
export type ActionSetQuizResults = Action<QuizAPIActionTypes.SET_QUIZ_RESULTS, {
    quizResults: QuizResultsResponse;
}>;
export type ActionSetCurrentQuestion = Action<QuizAPIActionTypes.SET_CURRENT_QUESTION, {
    quizCurrentQuestion: NextQuestionResponse;
    quizSessionId?: string;
    quizVersionId?: string;
}>;
export type ActionResetQuiz = Action<QuizAPIActionTypes.RESET_QUIZ>;
export type ActionQuizAPI = ActionSetIsLoading | ActionSetIsError | ActionSetQuizResults | ActionSetCurrentQuestion | ActionResetQuiz;
export {};
